OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "클립보드로 복사",
    "Copied!" : "복사 성공!",
    "Not supported!" : "지원되지 않습니다!",
    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
    "Press Ctrl-C to copy." : "복사하기 위해 Ctrl-C를 누르세요.",
    "First run wizard" : "첫 실행 마법사",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 프로필 사진과 이름을 입력하면 사용자를 빠르게 식별할 수 있습니다.",
    "Add your profile information! Set a full name for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 이름을 입력하면 사용자를 빠르게 식별할 수 있습니다.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "내 프로필 정보를 추가하십시오! 프로필 사진을 지정하면 사용자를 빠르게 식별할 수 있습니다.",
    "Schedule work & meetings, synced with all your devices." : "업우와 회의 일정을 짜고, 당신의 모든 기기와 동기화하세요.",
    "Keep your colleagues and friends in one place without leaking their private info." : "개인정보 누출 없이 동료와 친구들을 한 곳으로 모아두세요.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "파일 연락처 달력과 통합되는 간단한 이메일 앱",
    "About" : "정보",
    "Groupware apps like Calendar, Contacts, Mail" : "캘린더, 연락처, 메일과 같은 그룹웨어 앱들",
    "Communication with Nextcloud Talk" : "Nextcloud Talk와 대화",
    "Collaboration apps for document editing" : "문서 편집을 위한 협업 앱들",
    "Browse the App Store" : "앱 스토어에서 둘러보기",
    "Stay in sync" : "동기화",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud를 통해 당신의 파일을 어디에서든지 접근하세요.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "우리의 사용하기 쉬운 데스크톱 및 모바일 앱은 모든 메이저 플랫폼에서 무료로 제공됩니다!",
    "Get the apps to sync your files" : "파일 동기화 앱 가져오기",
    "Desktop client" : "데스크톱 클라이언트",
    "iOS app" : "iOS 앱",
    "Connect your desktop apps to %s" : "내 데스크톱 앱을 %s에 연결하기",
    "Connect your calendar" : "내 달력 연결",
    "Connect your contacts" : "내 연락처 연결",
    "Access files via WebDAV" : "WebDAV로 파일에 접근하기",
    "Get help" : "도움 받기",
    "Start contributing" : "기여 시작하기",
    "Enterprise support" : "엔터프라이즈 지원",
    "Get more information" : "추가 정보 얻기",
    "User manual" : "사용자 메뉴얼",
    "Admin manual" : "관리자 메뉴얼",
    "Developer manual" : "개발자 메뉴얼",
    "the Nextcloud forums" : "Nextcloud 포럼",
    "A safe home for all your data" : "내 모든 데이터를 위한 안전한 저장소",
    "Learn more about %s" : "%s에 관해 더 자세히 알아보기",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "당신이 있는 곳 어디에서나 %s가 당신의 파일에 접근할 수 있도록 도와줍니다. 쓰기 쉬운 데스크탑과 모바일 클라이언트를 대부분의 주요 플랫폼에서 무료로 이용하세요.",
    "Connect other apps to %s" : "다른 앱을 %s에 연결하세요.",
    "Server address" : "서버 주소",
    "Use this link to connect your apps and desktop client to this server:" : "다음 링크를 사용하여 데스크톱 클라이언트나 당신의 앱에 이 서버를 연결하세요.",
    "Copy link" : "링크 복사",
    "Android app" : "Android 앱",
    "Get enterprise support" : "기업 지원 받기"
},
"nplurals=1; plural=0;");
